@@ -3,12 +3,12 @@
 __all__ = ["extras_require"]
 
 extras_require = {
-		"readme": ["docutils==0.16", "readme-renderer[md]>=27.0"],
+		"readme": ["docutils>=0.16", "readme-renderer[md]>=27.0"],
 		"cli": ["click>=7.1.2", "consolekit>=1.4.1", "sdjson>=0.3.1"],
 		"all": [
 				"click>=7.1.2",
 				"consolekit>=1.4.1",
-				"docutils==0.16",
+				"docutils>=0.16",
 				"readme-renderer[md]>=27.0",
 				"sdjson>=0.3.1"
 				]
